Sepiida
=======

An API framework for common tasks/behavior for Authentise micro-service architecture.  Built on top of Flask, SQLAlchmeny, and Celery. Sepiida takes care of handling errors, REST methods, permissions(this is useful between microservices), creating and managing sessions, and more.

Used for creating APIs at Authentise.

Contact info@authentise.com if you want to learn more about using it. 

Features:  Filters
========
API's built in sepiida can take and process a standard set of URL filters to make it eaiser to shape and fliter data

Filters Examples:
 * page[offset]=NUMBER: Set how far into konwn data to paginate reults when there are many results
 * page[limit]=NUMBER: Set the count of how many responsees to return when paginating when there are many results


License
=======
The MIT License (MIT)

Copyright (c) 2016 Authentise Inc.

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
